@@ -34,7 +34,7 @@ class PytorchModuleProcessor:
     @staticmethod
     def describe(obj, **kwargs):
         import torch
-        print("Warn: Using simple Pytorch processor, please use kwarg 'input_size' for rich information")
+        print("Warn: Using simple Pytorch processor, please use kwarg 'input_size' or 'input_data' for rich information")
         print(obj)
 
 
